#!/bin/bash
set -euo pipefail

apt-get update
apt-get install -y curl

curl https://cursor.com/install -fsS | bash

echo 'export PATH="$HOME/.local/bin:$PATH"' >> ~/.bashrc
source ~/.bashrc

echo "INSTALL SUCCESS!"