window.__reactRouterManifest={"entry":{"module":"/assets/entry.client-Dk9HL2zZ.js","imports":["/assets/index-CYR-HZan.js"],"css":[]},"routes":{"root":{"id":"root","path":"","hasAction":false,"hasLoader":false,"hasClientAction":false,"hasClientLoader":false,"hasClientMiddleware":false,"hasErrorBoundary":true,"module":"/assets/root-B_7xc0ep.js","imports":["/assets/index-CYR-HZan.js","/assets/index-JVv6katd.js","/assets/mutation--h5hHClj.js","/assets/compare-Br3z3FUS-D09VrqaM.js"],"css":["/assets/root-BzmlCMuh.css"]},"routes/home":{"id":"routes/home","parentId":"root","index":true,"hasAction":false,"hasLoader":false,"hasClientAction":false,"hasClientLoader":false,"hasClientMiddleware":false,"hasErrorBoundary":false,"module":"/assets/home-BlsVvV_2.js","imports":["/assets/index-CYR-HZan.js","/assets/index-JVv6katd.js","/assets/api-BgrBwReI.js","/assets/empty-TlmgxYvO.js","/assets/input-BPzPo60M.js","/assets/hooks-CJW8H_7B.js","/assets/tooltip-CILBUYcN.js","/assets/kbd-CNHFVw7L.js","/assets/mutation--h5hHClj.js","/assets/index-DvJT0nJi.js","/assets/compare-Br3z3FUS-D09VrqaM.js","/assets/scroll-area-Bnf4hdko.js"],"css":[]},"routes/compare":{"id":"routes/compare","parentId":"root","path":"compare","hasAction":false,"hasLoader":false,"hasClientAction":false,"hasClientLoader":false,"hasClientMiddleware":false,"hasErrorBoundary":false,"module":"/assets/compare-wQy-Atyg.js","imports":["/assets/index-CYR-HZan.js","/assets/api-BgrBwReI.js","/assets/index-JVv6katd.js","/assets/index-DvJT0nJi.js","/assets/kbd-CNHFVw7L.js","/assets/tooltip-CILBUYcN.js"],"css":[]},"routes/job":{"id":"routes/job","parentId":"root","path":"jobs/:jobName","hasAction":false,"hasLoader":false,"hasClientAction":false,"hasClientLoader":false,"hasClientMiddleware":false,"hasErrorBoundary":false,"module":"/assets/job-C3lR1i4o.js","imports":["/assets/index-CYR-HZan.js","/assets/api-BgrBwReI.js","/assets/index-JVv6katd.js","/assets/empty-TlmgxYvO.js","/assets/input-BPzPo60M.js","/assets/tooltip-CILBUYcN.js","/assets/code-block-CUSGUC3x.js","/assets/hooks-CJW8H_7B.js","/assets/tabs-DnzvJY73.js","/assets/kbd-CNHFVw7L.js","/assets/mutation--h5hHClj.js","/assets/index-DvJT0nJi.js","/assets/compare-Br3z3FUS-D09VrqaM.js","/assets/scroll-area-Bnf4hdko.js"],"css":[]},"routes/task":{"id":"routes/task","parentId":"root","path":"jobs/:jobName/tasks/:source/:agent/:modelProvider/:modelName/:taskName","hasAction":false,"hasLoader":false,"hasClientAction":false,"hasClientLoader":false,"hasClientMiddleware":false,"hasErrorBoundary":false,"module":"/assets/task-NN6Wy6Uf.js","imports":["/assets/index-CYR-HZan.js","/assets/api-BgrBwReI.js","/assets/code-block-CUSGUC3x.js","/assets/hooks-CJW8H_7B.js","/assets/kbd-CNHFVw7L.js","/assets/index-JVv6katd.js","/assets/scroll-area-Bnf4hdko.js"],"css":[]},"routes/trial":{"id":"routes/trial","parentId":"root","path":"jobs/:jobName/tasks/:source/:agent/:modelProvider/:modelName/:taskName/trials/:trialName","hasAction":false,"hasLoader":false,"hasClientAction":false,"hasClientLoader":false,"hasClientMiddleware":false,"hasErrorBoundary":false,"module":"/assets/trial-CcF5MMCl.js","imports":["/assets/index-CYR-HZan.js","/assets/api-BgrBwReI.js","/assets/index-JVv6katd.js","/assets/empty-TlmgxYvO.js","/assets/tabs-DnzvJY73.js","/assets/index-DvJT0nJi.js","/assets/scroll-area-Bnf4hdko.js","/assets/code-block-CUSGUC3x.js","/assets/mutation--h5hHClj.js"],"css":[]}},"url":"/assets/manifest-e7e139aa.js","version":"e7e139aa"};